.. image:: http://dahlia.github.com/wand/_static/wand_120.png

Wand_
~~~~~

Wand is a ``ctypes``-based simple ImageMagick_ binding for Python.
It doesn't cover all functionalities of MagickWand API currently.

You can install the package from PyPI_ by using ``pip`` or
``easy_install``::

    $ pip install Wand

Or would you like to enjoy with bleeding edge?  Check out the head
revision of the source code from the `GitHub repository`__::

    $ git clone git://github.com/dahlia/wand.git
    $ cd wand/
    $ python setup.py install

.. _Wand: http://dahlia.kr/wand/
.. _ImageMagick: http://www.imagemagick.org/
.. _PyPI: http://pypi.python.org/pypi/Wand
__ https://github.com/dahlia/wand


Community
---------

GitHub
   https://github.com/dahlia/wand

Mailing list
   wand@librelist.com

List archive
   http://librelist.com/browser/wand/

IRC
   irc://irc.freenode.net/wand

Continuous Integration (Travis CI)
   http://travis-ci.org/dahlia/wand

   .. image:: https://secure.travis-ci.org/dahlia/wand.png?branch=master
      :alt: Build Status
      :target: http://travis-ci.org/dahlia/wand
